:orphan:

.. _whats_new_v0p1:

*********************************
What's New in Cosmo-Utils v0.1?
*********************************

- Updated paths and fixed bugs.
- Fixed bugs with functions and missing arguments (:py:func:`~cosmo_utils.utils.stats_funcs.sigma_calcs` and :py:func:`~cosmo_utils.mock_catalogues.catls_utils.sdss_catl_clean_nmin`)